@@ -38,7 +38,7 @@
 # include <getopt.h>
 #endif
 
-#ifdef IPFILTER
+#if defined(IPFILTER) && (defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__))
 # include <sys/ioctl.h>
 # include <netinet/in_systm.h>
 # include <netinet/ip.h>
@@ -49,7 +49,7 @@
 # include <netinet/ip_nat.h>
 #endif
 
-#ifdef IPTABLES
+#if defined(IPTABLES) && defined(__linux__)
 # include <linux/netfilter_ipv4.h>
 #endif
 
@@ -62,7 +62,7 @@
 # define INADDR_NONE		(in_addr_t)-1
 #endif
 
-/* For Linux */
+/* For older Linux */
 #if defined(SIGCLD) && !defined(SIGCHLD)
 # define SIGCHLD			SIGCLD
 #endif
@@ -1014,7 +1014,7 @@ static void trans_proxy(int sock, struct sockaddr_in *from_addr,
 	conn.parse_state = PS_METHOD;
 	conn.parse_state = PS_METHOD;
 
-#ifdef IPTABLES
+#if defined(IPTABLES) && defined(__linux__)
 	/*
 	 * The first thing we do is get the IP address that the client was
 	 * trying to connected to. Here lies part of the magic. Linux-2.4
